from .main import run  # noqa: F401
from .utils.logger import configure_logging

configure_logging()
